==> kubernetes-model-1.0.63-sources.jar: annotations/io/fabric8/kubernetes/api/model/LocalObjectReferenceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.util.Set;
import java.lang.Object;

public class LocalObjectReferenceBuilder extends LocalObjectReferenceFluentImpl<LocalObjectReferenceBuilder> implements VisitableBuilder<LocalObjectReference,LocalObjectReferenceBuilder>{

    LocalObjectReferenceFluent<?> fluent;
    Boolean validationEnabled;

    public LocalObjectReferenceBuilder(){
            this(true);
    }
    public LocalObjectReferenceBuilder(Boolean validationEnabled){
            this(new LocalObjectReference(), validationEnabled);
    }
    public LocalObjectReferenceBuilder(LocalObjectReferenceFluent<?> fluent){
            this(fluent, true);
    }
    public LocalObjectReferenceBuilder(LocalObjectReferenceFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new LocalObjectReference(), validationEnabled);
    }
    public LocalObjectReferenceBuilder(LocalObjectReferenceFluent<?> fluent,LocalObjectReference instance){
            this(fluent, instance, true);
    }
    public LocalObjectReferenceBuilder(LocalObjectReferenceFluent<?> fluent,LocalObjectReference instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withName(instance.getName()); 
            this.validationEnabled = validationEnabled; 
    }
    public LocalObjectReferenceBuilder(LocalObjectReference instance){
            this(instance,true);
    }
    public LocalObjectReferenceBuilder(LocalObjectReference instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withName(instance.getName()); 
            this.validationEnabled = validationEnabled; 
    }

    public LocalObjectReference build(){
            LocalObjectReference buildable = new LocalObjectReference(fluent.getName());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            LocalObjectReferenceBuilder that = (LocalObjectReferenceBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-1.0.64-sources.jar: annotations/io/fabric8/kubernetes/api/model/LocalObjectReferenceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import javax.annotation.Generated;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;

public class LocalObjectReferenceBuilder extends LocalObjectReferenceFluentImpl<LocalObjectReferenceBuilder> implements VisitableBuilder<LocalObjectReference,LocalObjectReferenceBuilder>{

    LocalObjectReferenceFluent<?> fluent;
    Boolean validationEnabled;

    public LocalObjectReferenceBuilder(){
            this(true);
    }
    public LocalObjectReferenceBuilder(Boolean validationEnabled){
            this(new LocalObjectReference(), validationEnabled);
    }
    public LocalObjectReferenceBuilder(LocalObjectReferenceFluent<?> fluent){
            this(fluent, true);
    }
    public LocalObjectReferenceBuilder(LocalObjectReferenceFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new LocalObjectReference(), validationEnabled);
    }
    public LocalObjectReferenceBuilder(LocalObjectReferenceFluent<?> fluent,LocalObjectReference instance){
            this(fluent, instance, true);
    }
    public LocalObjectReferenceBuilder(LocalObjectReferenceFluent<?> fluent,LocalObjectReference instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withName(instance.getName()); 
            this.validationEnabled = validationEnabled; 
    }
    public LocalObjectReferenceBuilder(LocalObjectReference instance){
            this(instance,true);
    }
    public LocalObjectReferenceBuilder(LocalObjectReference instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withName(instance.getName()); 
            this.validationEnabled = validationEnabled; 
    }

    public LocalObjectReference build(){
            LocalObjectReference buildable = new LocalObjectReference(fluent.getName());
            io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable);
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            LocalObjectReferenceBuilder that = (LocalObjectReferenceBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
